<p align="center">
    <img width="350" height="350" src="https://github.com/Sorosliu1029/cosmos-wormhole/blob/master/docs/logo.png" alt="cosmos wormhole" style="display: block; margin: auto; width: 30%"/>
</p>
<p align="center">
    <strong>cosmos-wormhole</strong> <em>- <a href="https://www.xiaoyuzhoufm.com/" target="_blank">小宇宙</a> API (Python Version)</em>
</p>
<p align="center">
    <a href="https://pypi.org/project/cosmos-wormhole" target="_blank"><img src="https://badge.fury.io/py/cosmos-wormhole.svg?icon=si%3Apython" alt="PyPI version"></a>
</p>

### 安装

```sh
pip install cosmos-wormhole
```

### 用法

见 https://cosmos-wormhole.sorosliu.xyz/

### ⚠️

非官方SDK，请谨慎合理使用。

仅提供并维护当前所写的功能。

需要新功能的请自行扩展代码，不接受新功能的PR。

但欢迎对当前代码的PR（包括但不限于测试用例、文档、性能优化）。
